---
title: About
type: about
weight: 99
prev: docs
next: index
---

`PETsARD` project commenced in 2023 as a privacy-enhancing initiative led and guided by the Ministry of Digital Affairs, and executed by the National Institute of Cyber Security in Taiwan.

In December 2024, PETsARD v1.0 was officially released to the Ministry of Digital Affairs (moda). The package continues to be actively developed under the National Institute of Cyber Security (NICS), and welcomes contact and contributions from interested collaborators.

## License

This project is licensed under `MIT` License with additional restrictions due to dependencies. The most significant restriction comes from SDV's Business Source License 1.1, which prohibits using this software as a commercial synthetic data service. For detailed licensing information, please see the LICENSE file.

Key Dependencies' Licenses:

- SDV: Business Source License 1.1
- Anonymeter: The Clear BSD License
- SDMetrics: MIT License

For commercial use involving synthetic data services, please contact DataCebo, Inc.

## Citation

- `Synthesizer` module:
  - SDV - [sdv-dev/SDV](https://github.com/sdv-dev/SDV):
    - Patki, N., Wedge, R., & Veeramachaneni, K. (2016). The Synthetic Data Vault. IEEE International Conference on Data Science and Advanced Analytics (DSAA), 399–410. https://doi.org/10.1109/DSAA.2016.49
- `Evaluator` module:
  - Anonymeter - [statice/anonymeter](https://github.com/statice/anonymeter):
    - Giomi, M., Boenisch, F., Wehmeyer, C., & Tasnádi, B. (2023). A Unified Framework for Quantifying Privacy Risk in Synthetic Data. Proceedings of Privacy Enhancing Technologies Symposium. https://doi.org/10.56553/popets-2023-0055
  - SDMetrics - [sdv-dev/SDMetrics](https://github.com/sdv-dev/SDMetrics)
